@@ -8,6 +8,7 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QResizeEvent>
+#include <QLabel>
 #include <QUrl>
 #include <QSettings>
 #include "progressdialog.h"
@@ -46,7 +47,6 @@ private:
     QList<DayPeriod*>* dayPeriods;
     QPixmap** iconCache; //array of icon pointers
     QIcon *icon;
-    int iconCount;
     bool needShowList;
     bool justStarted;
     ProgressDialog *pg;
@@ -54,6 +54,8 @@ private:
     void detailWindow(int day);
     void setDomDocument(QString* reply);
     void deleteCache();
+    void colorize(QLabel* label);
+    void parse_for_wfo(QDomElement* domElement);
     QList<QString*>* parse_for_temps(QDomElement* domElement);
     QList<QString*>* parse_for_days(QDomElement* domElement);
     QList<QString*>* parse_for_precip(QDomElement* domElement);
@@ -70,9 +72,9 @@ private slots:
     void changeZip();
     void setSettings();
     void visitNAOO();
-    void zipEvent(){
-        changeZip();
-    }
+//    void zipEvent(){
+//        changeZip();
+//    }
 
 
 };
