@@ -12,6 +12,10 @@ SettingsDialog::SettingsDialog(QVariant *home1, QVariant *home2, QVariant *defau
     ui->home2Entry->setInputMethodHints((Qt::ImhDigitsOnly));
     ui->activeComboBox->setCurrentIndex(defaultHome->toInt());
 
+    ui->line->setPalette(QApplication::palette().highlight().color());
+    ui->line_2->setPalette(QApplication::palette().highlight().color());
+    ui->line_3->setPalette(QApplication::palette().highlight().color());
+
     this->home1 = new QVariant(*home1);
     this->home2 = new QVariant(*home2);
     this->defaultHome = new QVariant(*defaultHome);
@@ -27,6 +31,14 @@ SettingsDialog::~SettingsDialog()
     delete defaultHome;
 }
 
+void SettingsDialog::resizeEvent(QResizeEvent *event){
+	if(event->oldSize().width() > event->size().width()){
+		ui->mainLayout->setDirection(QBoxLayout::TopToBottom);
+	}else{
+		ui->mainLayout->setDirection(QBoxLayout::LeftToRight);
+	}
+}
+
 void SettingsDialog::setValues(){
     home1 = new QVariant(ui->home1Entry->text());
     home2 = new QVariant(ui->home2Entry->text());
