@@ -2,6 +2,7 @@
 #define SETTINGSDIALOG_H
 
 #include <QDialog>
+#include <QResizeEvent>
 
 namespace Ui {
     class SettingsDialog;
@@ -18,6 +19,9 @@ public:
     QVariant* getHome2();
     QVariant* getDefaultHome();
 
+protected:
+	virtual void resizeEvent(QResizeEvent * event);
+
 
 private:
     Ui::SettingsDialog *ui;
