@@ -7,6 +7,7 @@
 #include <QUrl>
 #include <QNetworkReply>
 #include <QSignalMapper>
+#include <QLabel>
 
 namespace Ui {
     class StackedWindow;
@@ -34,6 +35,7 @@ private:
     Ui::StackedWindow *ui;
     QSignalMapper* mapper;
     QNetworkAccessManager *manager;
+    void colorize(QLabel* label);
 };
 
 #endif // STACKEDWINDOW_H
